[Bf-blender-cvs] [aa49c16] master: Cleanup: Avoid some warnings on OS X with clang and update comment.

Thomas Dinges noreply at git.blender.org
Mon Oct 26 11:52:52 CET 2015


Commit: aa49c16bd94f0ef38edcc1e24e90717799354445
Author: Thomas Dinges
Date:   Sun Oct 25 20:48:28 2015 +0100
Branches: master
https://developer.blender.org/rBaa49c16bd94f0ef38edcc1e24e90717799354445

Cleanup: Avoid some warnings on OS X with clang and update comment.

===================================================================

M	intern/cycles/kernel/kernel_compat_cpu.h
M	intern/cycles/kernel/osl/osl_services.cpp
M	intern/cycles/util/util_optimization.h

===================================================================

diff --git a/intern/cycles/kernel/kernel_compat_cpu.h b/intern/cycles/kernel/kernel_compat_cpu.h
index 04c4cf3..baa67f6 100644
--- a/intern/cycles/kernel/kernel_compat_cpu.h
+++ b/intern/cycles/kernel/kernel_compat_cpu.h
@@ -22,7 +22,7 @@
 /* Release kernel has too much false-positive maybe-uninitialized warnings,
  * which makes it possible to miss actual warnings.
  */
-#if defined(__GNUC__) && defined(NDEBUG)
+#if (defined(__GNUC__) && !defined(__clang__)) && defined(NDEBUG)
 #  pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
 #  pragma GCC diagnostic ignored "-Wuninitialized"
 #endif
diff --git a/intern/cycles/kernel/osl/osl_services.cpp b/intern/cycles/kernel/osl/osl_services.cpp
index 3c1955a..b0609ad 100644
--- a/intern/cycles/kernel/osl/osl_services.cpp
+++ b/intern/cycles/kernel/osl/osl_services.cpp
@@ -18,7 +18,7 @@
  * here, so for now we just put here. In the future it might be better
  * to have dedicated file for such tweaks.
  */
-#if defined(__GNUC__) && defined(NDEBUG)
+#if (defined(__GNUC__) && !defined(__clang__)) && defined(NDEBUG)
 #  pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
 #  pragma GCC diagnostic ignored "-Wuninitialized"
 #endif
diff --git a/intern/cycles/util/util_optimization.h b/intern/cycles/util/util_optimization.h
index 42d3ca6..b1f9ee6 100644
--- a/intern/cycles/util/util_optimization.h
+++ b/intern/cycles/util/util_optimization.h
@@ -23,7 +23,9 @@
 #if defined(__KERNEL_SSE2__)  || \
 	defined(__KERNEL_SSE3__)  || \
 	defined(__KERNEL_SSSE3__) || \
-	defined(__KERNEL_SSE41__)
+	defined(__KERNEL_SSE41__) || \
+	defined(__KERNEL_AVX__)   || \
+	defined(__KERNEL_AVX2__)
 	/* do nothing */
 #endif
 
@@ -45,7 +47,7 @@
 
 /* x86-64
  *
  * Compile a regular (includes SSE2), SSE3 and SSE 4.1 kernel. */
 
 #if defined(__x86_64__) || defined(_M_X64)
@@ -45,7 +47,7 @@
 /* x86-64
  *
- * Compile a regular (includes SSE2), SSE3 and SSE 4.1 kernel. */
+ * Compile a regular (includes SSE2), SSE3, SSE 4.1, AVX and AVX2 kernel. */
 
 #if defined(__x86_64__) || defined(_M_X64)




More information about the Bf-blender-cvs mailing list